@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 from transliterate import get_translit_function
 from transliterate.base import TranslitLanguagePack, registry
 
@@ -7,8 +9,8 @@ class KazakhLanguagePack(TranslitLanguagePack):
     language_name = "Kazakh"
 
     mapping = (
-        u"аәбвгғдеёжзийкқлмнңоөпрстуұүфхһцъыіьэАӘБВГҒДЕЁЖЗИЙКҚЛМНҢОӨПРСТУҰҮФХҺЦЪЫІЬЭ",
-        u"aábvgǵdeejzııkqlmnńoóprstýuúfhhc'yi'eAÁBVGǴDEEJZIIKQLMNŃOÓPRSTÝUÚFHHC'YI'E"
+        u"аәбвгғдеёжзийкқлмнңоөпрстуұүфхһцшъыіьэАӘБВГҒДЕЁЖЗИЙКҚЛМНҢОӨПРСТУҰҮФХҺЦШЪЫІЬЭ",
+        u"aäbvgğdeejziikqlmnŋoöprstuūüfhhcş'yı'eAÄBVGĞDEEJZİİKQLMNŊOÖPRSTUŪÜFHHCŞ'YI'E"
     )
 
     # TODO
@@ -21,15 +23,13 @@ class KazakhLanguagePack(TranslitLanguagePack):
 
     pre_processor_mapping = {
         u"ч": u"ch",
-        u"ш": u"sh",
-        u"щ": u"sch",
-        u"ю": u"ıý",
-        u"я": u"ıa",
+        u"щ": u"şh",
+        u"ю": u"iu",
+        u"я": u"ia",
         u"Ч": u"Ch",
-        u"Ш": u"Sh",
-        u"Щ": u"Sch",
-        u"Ю": u"Iý",
-        u"Я": u"Ia",
+        u"Щ": u"Şh",
+        u"Ю": u"İu",
+        u"Я": u"İa",
     }
 
 
@@ -37,6 +37,7 @@ registry.register(KazakhLanguagePack)
 
 translit_kk = get_translit_function("kk")
 
+
 def translit(value: str) -> str:
     """Transliterate the text."""
-    return translit_kk(value)
\ No newline at end of file
+    return translit_kk(value)
